#include "util.h"

using namespace dpp;

#define SR_IMAGE "https://i.imgur.com/MV4i9oF.png"

uint32_t util::getHexColor(EmbedType type) {
    switch (type) {
        case ERROR:
            return 0xde1f1f;
        case SUCCESS:
            return 0x2ecc71;
        case INFO:
            return 0x748AD6;
    }
    return 0x000000;
}

embed util::getDefaultEmbed(EmbedType type) {
    embed e;
    e.set_footer("Sheepstar", SR_IMAGE);
    e.set_timestamp(time(nullptr));
    e.set_color(getHexColor(type));
    return e;
}

void util::sendSuccess(const dpp::slashcommand_t &event, const std::string &message) {
    embed e = getDefaultEmbed(SUCCESS);
    e.set_title("Success");
    e.set_description("> " + std::regex_replace(message, std::regex("\n"), "\n> "));

    event.reply(dpp::message().add_embed(e).set_flags(dpp::m_ephemeral));
}

void util::sendError(const dpp::slashcommand_t &event, const std::string &message) {
    embed e = getDefaultEmbed(ERROR);
    e.set_title("<:max:1170311480160292894>  An error occurred");
    e.set_description("> " + std::regex_replace(message, std::regex("\n"), "\n> "));

    event.reply(dpp::message().add_embed(e).set_flags(dpp::m_ephemeral));
}

sql::Connection *util::createConnection(const json &config) {
    sql::Driver *driver = sql::mariadb::get_driver_instance();

    sql::SQLString url = "jdbc:" + config["string"].get<std::string>();

    sql::Properties properties({{"user",          config["username"].get<std::string>()},
                                {"password",      config["password"].get<std::string>()},
                                {"autoReconnect", "true"},
                                {"maxReconnects", "500"}});

    sql::Connection *con = driver->connect(url, properties);
    return con;
}

sql::ResultSet *util::getResultSet(sql::Connection &con, const std::string &query,
                                   std::initializer_list<std::string> params) {
    sql::PreparedStatement *stmt = con.prepareStatement(query);

    int i = 1;
    for (auto &param: params) {
        stmt->setString(i, param);
        i++;
    }

    return stmt->executeQuery();
}

void util::executeQuery(sql::Connection &con, const std::string &query, std::initializer_list<std::string> params) {
    sql::PreparedStatement *stmt = con.prepareStatement(query);

    int i = 1;
    for (auto &param: params) {
        stmt->setString(i, param);
        i++;
    }

    stmt->execute();
}